@@ -14,7 +14,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
+import os
 import sys
+import tyrs
 from htmlentitydefs import entitydefs
 
 def set_console_title():
@@ -29,7 +31,10 @@ def cut_attag(name):
     return name
 
 def encode(string):
-    return string.encode(sys.stdout.encoding)
+    try:
+        return string.encode(sys.stdout.encoding)
+    except AttributeError:
+        return string
 
 def html_unescape(str):
     """ Unescapes HTML entities """
@@ -41,3 +46,24 @@ def html_unescape(str):
             return m.group(0)
 
     return re.sub(r'&([^;]+);', entity_replacer, str)
+
+
+def get_source(source):
+    if source == 'web':
+        return source
+    source = source.split('>')
+    source = source[1:]
+    source = ' '.join(source)
+    source = source.split('<')[:1]
+    source = source[:1]
+    source = ' '.join(source)
+    return source
+
+def open_image(user):
+    image = user.profile_image_url
+    command = tyrs.container['conf'].params['open_image_command']
+    os.system(command % image)
+
+
+def get_urls(text):
+    return re.findall('http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+', text)
